@@ -38,7 +38,6 @@ import Control.Applicative
 import Control.Monad
 import Language.Haskell.TH.Lens
 import Language.Haskell.TH
-import Data.Foldable (toList)
 import Data.Maybe (isJust,maybeToList)
 import Data.List (nub, findIndices)
 import Data.Either (partitionEithers)
@@ -592,16 +591,17 @@ data DefName
 -- | Template Haskell wants type variables declared in a forall, so
 -- we find all free type variables in a given type and declare them.
 quantifyType :: Cxt -> Type -> Type
-quantifyType c t = ForallT vs c t
-  where
-  vs = map PlainTV (toList (setOf typeVars t))
+quantifyType = quantifyType' Set.empty
 
 -- | This function works like 'quantifyType' except that it takes
 -- a list of variables to exclude from quantification.
 quantifyType' :: Set Name -> Cxt -> Type -> Type
 quantifyType' exclude c t = ForallT vs c t
   where
-  vs = map PlainTV (toList (setOf typeVars t Set.\\ exclude))
+  vs = map PlainTV
+     $ filter (`Set.notMember` exclude)
+     $ nub -- stable order
+     $ toListOf typeVars t
 
 
 ------------------------------------------------------------------------
