@@ -10,11 +10,7 @@
 #define MIN_VERSION_mtl(x,y,z) 1
 #endif
 
-#ifndef MIN_VERSION_profunctors
-#define MIN_VERSION_profunctors(x,y,z) 1
-#endif
-
-#if __GLASGOW_HASKELL__ < 708 || !(MIN_VERSION_profunctors(4,4,0))
+#if __GLASGOW_HASKELL__ < 708
 {-# LANGUAGE Trustworthy #-}
 #endif
 -------------------------------------------------------------------------------
@@ -372,15 +368,15 @@ as <&> f = f <$> as
 -- @
 -- fab ?? a = fmap ($ a) fab
 -- @
--- 
+--
 -- For the 'Functor' instance @f = ((->) r)@ you can reason about this function as if the definition was @('??') ≡ 'flip'@:
--- 
+--
 -- >>> (h ?? x) a
 -- h a x
--- 
+--
 -- >>> execState ?? [] $ modify (1:)
 -- [1]
--- 
+--
 -- >>> over _2 ?? ("hello","world") $ length
 -- ("hello",5)
 --
@@ -1212,6 +1208,9 @@ l <<>= r = l <%= (`mappend` r)
 -- 'Control.Lens.Setter.Setter', but requires a full lens, or close
 -- enough.
 --
+-- >>> overA _1 ((+1) *** (+2)) ((1,2),6)
+-- ((2,4),6)
+--
 -- @
 -- overA :: Arrow ar => Lens s t a b -> ar a b -> ar s t
 -- @
