@@ -152,7 +152,8 @@ import Data.Functor.Day.Curried
 import Data.Functor.Yoneda
 import Data.Int
 import Data.IntMap as IntMap
-import Data.Map as Map
+import qualified Data.Map as Map
+import Data.Map (Map)
 import Data.Sequence (Seq, mapWithIndex)
 import Data.Vector as Vector (Vector, imap)
 import Data.Monoid
@@ -172,7 +173,7 @@ import Prelude hiding ((.),id)
 -- >>> :set -XNoOverloadedStrings
 -- >>> import Control.Lens
 -- >>> import Control.DeepSeq (NFData (..), force)
--- >>> import Control.Exception (evaluate)
+-- >>> import Control.Exception (evaluate,try,ErrorCall(..))
 -- >>> import Data.Maybe (fromMaybe)
 -- >>> import Debug.SimpleReflect.Vars
 -- >>> import Data.Void
@@ -636,8 +637,7 @@ holesOf l s = unTagged
 -- >>> [1,2,3] ^. singular _head
 -- 1
 --
--- >>> [] ^. singular _head
--- *** Exception: singular: empty traversal
+-- >>> Left (ErrorCall "singular: empty traversal") <- try (evaluate ([] ^. singular _head)) :: IO (Either ErrorCall ())
 --
 -- >>> Left 4 ^. singular _Left
 -- 4
@@ -672,8 +672,7 @@ singular l = conjoined
 -- The resulting 'Lens' or 'Getter' will be partial if the 'Traversal' targets nothing
 -- or more than one element.
 --
--- >>> [] & unsafeSingular traverse .~ 0
--- *** Exception: unsafeSingular: empty traversal
+-- >>> Left (ErrorCall "unsafeSingular: empty traversal") <- try (evaluate ([] & unsafeSingular traverse .~ 0)) :: IO (Either ErrorCall [Integer])
 --
 -- @
 -- 'unsafeSingular' :: 'Traversal' s t a b          -> 'Lens' s t a b
