@@ -90,6 +90,7 @@ import           Control.Lens.Review
 #endif
 import           Control.Monad.Trans.Cont
 import           Control.Monad.Trans.Error
+import           Control.Monad.Trans.Except
 import           Control.Monad.Trans.Identity
 import           Control.Monad.Trans.List
 import           Control.Monad.Trans.Maybe
@@ -315,6 +316,12 @@ instance Wrapped (ErrorT e m a) where
   _Wrapped' = iso runErrorT ErrorT
   {-# INLINE _Wrapped' #-}
 
+instance (t ~ ExceptT e' m' a') => Rewrapped (ExceptT e m a) t
+instance Wrapped (ExceptT e m a) where
+  type Unwrapped (ExceptT e m a) = m (Either e a)
+  _Wrapped' = iso runExceptT ExceptT
+  {-# INLINE _Wrapped' #-}
+
 instance (t ~ Identity b) => Rewrapped (Identity a) t
 instance Wrapped (Identity a) where
   type Unwrapped (Identity a) = a
@@ -710,9 +717,6 @@ _Unwrapping _ = from _Wrapped
 -- >>> ala Any foldMap [True,False]
 -- True
 --
--- >>> ala Sum foldMap [1,2,3,4]
--- 10
---
 -- >>> ala Product foldMap [1,2,3,4]
 -- 24
 --
